package cn.com.qmth.examcloud.service.core.api;

import cn.com.qmth.examcloud.service.core.dao.CourseRepo;
import cn.com.qmth.examcloud.service.core.entity.Course;
import cn.com.qmth.examcloud.service.core.service.CourseService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * 课程服务API
 * Created by songyue on 17/1/14.
 */
@RestController
@RequestMapping("${app.api.root}/course")
public class CourseApi {

    @Autowired
    CourseRepo courseRepo;

    @Autowired
    CourseService courseService;

    @ApiOperation(value="查询所有课程",notes="分页")
    @GetMapping("/all/{curPage}/{pageSize}")
    public ResponseEntity getAllCourse(@ModelAttribute Course courseCriteria, @PathVariable Integer curPage, @PathVariable Integer pageSize){
        return courseService.getAllCourse(courseCriteria,new PageRequest(curPage - 1,pageSize));
    }

    @ApiOperation(value="查询所有课程",notes="不分页")
    @GetMapping("/all")
    public ResponseEntity getAllCourse(@ModelAttribute Course courseCriteria){
        return courseService.getAllCourse(courseCriteria);
    }

    @ApiOperation(value="按ID查询课程",notes="ID查询")
    @GetMapping("/{id}")
    public ResponseEntity<Course> getCourseById(@PathVariable Long id){
        return courseService.getCourseById(id);
    }

    @ApiOperation(value="新增课程",notes="新增")
    @PostMapping
    public ResponseEntity addCourse(@ModelAttribute Course course){
        return courseService.saveCourse(course);
    }

    @ApiOperation(value="更新课程",notes="更新")
    @PutMapping
    public ResponseEntity updateCourse(@ModelAttribute Course course){
        return courseService.saveCourse(course);
    }

    @ApiOperation(value="按ID删除课程",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteCourse(@PathVariable Long id){
        return courseService.deleteCourse(id);
    }
}
