package cn.com.qmth.examcloud.service.core.api;

import cn.com.qmth.examcloud.service.core.dao.StudentRepo;
import cn.com.qmth.examcloud.service.core.entity.Student;
import cn.com.qmth.examcloud.service.core.service.StudentService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * 学生服务API
 * Created by songyue on 17/1/14.
 */
@RestController
@RequestMapping("${app.api.root}/student")
public class StudentApi {

    @Autowired
    StudentRepo studentRepo;

    @Autowired
    StudentService studentService;

    @ApiOperation(value="查询所有学生",notes="分页")
    @GetMapping("/all/{curPage}/{pageSize}")
    public ResponseEntity getAllStudent(@ModelAttribute Student studentCriteria, @PathVariable Integer curPage, @PathVariable Integer pageSize){
        return studentService.getAllStudent(studentCriteria,new PageRequest(curPage - 1,pageSize));
    }

    @ApiOperation(value="查询所有学生",notes="不分页")
    @GetMapping("/all")
    public ResponseEntity getAllStudent(@ModelAttribute Student studentCriteria){
        return studentService.getAllStudent(studentCriteria);
    }

    @ApiOperation(value="按ID查询学生",notes="ID查询")
    @GetMapping("/{id}")
    public ResponseEntity<Student> getStudentById(@PathVariable Long id){
        return studentService.getStudentById(id);
    }

    @ApiOperation(value="新增学生",notes="新增")
    @PostMapping
    public ResponseEntity addStudent(@ModelAttribute Student student){
        return studentService.saveStudent(student);
    }

    @ApiOperation(value="更新学生",notes="更新")
    @PutMapping
    public ResponseEntity updateStudent(@ModelAttribute Student student){
        return studentService.saveStudent(student);
    }

    @ApiOperation(value="按ID删除学生",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteStudent(@PathVariable Long id){
        return studentService.deleteStudent(id);
    }
}
