package cn.com.qmth.usercloud.service.core.api;

import cn.com.qmth.examcloud.service.core.dao.UserRepo;
import cn.com.qmth.examcloud.service.core.entity.User;
import cn.com.qmth.examcloud.service.core.service.UserService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * 用户服务API
 * Created by songyue on 17/1/13.
 */
@RestController
@RequestMapping("${app.api.root}/user")
public class UserApi {

    @Autowired
    UserService userService;

    @Autowired
    UserRepo userRepo;

    @ApiOperation(value="查询所有用户",notes="分页")
    @GetMapping("/all/{curPage}/{pageSize}")
    public ResponseEntity getAllUser(@ModelAttribute User userCriteria, @PathVariable Integer curPage, @PathVariable Integer pageSize){
        return userService.getAllUser(userCriteria,new PageRequest(curPage - 1,pageSize));
    }

    @ApiOperation(value="查询所有用户",notes="不分页")
    @GetMapping("/all")
    public ResponseEntity getAllUser(@ModelAttribute User userCriteria){
        return userService.getAllUser(userCriteria);
    }

    @ApiOperation(value="按ID查询用户",notes="ID查询")
    @GetMapping("/{id}")
    public ResponseEntity<User> getUserById(@PathVariable Long id){
        return userService.getUserById(id);
    }

    @ApiOperation(value="新增用户",notes="新增")
    @PostMapping
    public ResponseEntity addUser(@ModelAttribute User user){
        return userService.saveUser(user);
    }

    @ApiOperation(value="更新用户",notes="更新")
    @PutMapping
    public ResponseEntity updateUser(@ModelAttribute User user){
        return userService.saveUser(user);
    }

    @ApiOperation(value="按ID删除用户",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteUser(@PathVariable Long id){
        return userService.deleteUser(id);
    }
}
