package cn.com.qmth.examcloud.service.core.service;

import cn.com.qmth.examcloud.service.core.dao.UserRepo;
import cn.com.qmth.examcloud.service.core.entity.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

/**
 * 用户服务类
 * Created by songyue on 17/1/13.
 */
@Service
public class UserService {

    @Autowired
    UserRepo userRepo;

    /**
     * 获取所有用户(分页)
     * @param userCriteria
     * @param pageable
     * @return
     */
    public ResponseEntity getAllUser(User userCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("userName",startsWith())
                .withMatcher("loginName",startsWith());
        Example<User> userExample = Example.of(userCriteria, exampleMatcher);
        return new ResponseEntity(userRepo.findAll(userExample,pageable), HttpStatus.OK);
    }

    /**
     * 获取所有用户
     * @param userCriteria
     * @return
     */
    public ResponseEntity getAllUser(User userCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("userName",startsWith())
                .withMatcher("loginName",startsWith());
        Example<User> userExample = Example.of(userCriteria, exampleMatcher);
        return new ResponseEntity(userRepo.findAll(userExample), HttpStatus.OK);
    }

    /**
     * 按ID获取用户
     * @param id
     * @return
     */
    public ResponseEntity<User> getUserById(Long id){
        return new ResponseEntity<User>(userRepo.findOne(id),HttpStatus.OK);
    }

    /**
     * 保存用户
     * @param user
     * @return
     */
    public ResponseEntity saveUser(User user){
        return new ResponseEntity(userRepo.save(user),HttpStatus.OK);
    }

    /**
     * 删除用户
     * @param id
     * @return
     */
    public ResponseEntity deleteUser(Long id){
        userRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 删除所有用户
     * @return
     */
    public ResponseEntity deleteAllUser(){
        userRepo.deleteAll();
        return new ResponseEntity(HttpStatus.OK);
    }
}
